@@ -3,10 +3,12 @@
 
 // Constants
 
-static const int max_speed = 2300;
 static const double jump_max_duration = 0.2;
 static const double jump_speed = 291 + (2 / 3);
 static const double jump_acc = 1458 + (1 / 3);
+static const double boost_consumption = 33. + (1. / 3.);
+static const double max_speed = 2300;
+static const double simulation_dt = 1. / 30.;
 
 // Vector stuff
 
@@ -35,32 +37,32 @@ struct opti_norm
 Vector add(Vector vec1, Vector vec2)
 {
     return (Vector){vec1.x + vec2.x, vec1.y + vec2.y, vec1.z + vec2.z};
-};
+}
 
 Vector sub(Vector vec1, Vector vec2)
 {
     return (Vector){vec1.x - vec2.x, vec1.y - vec2.y, vec1.z - vec2.z};
-};
+}
 
 Vector multiply(Vector vec1, Vector vec2)
 {
     return (Vector){vec1.x * vec2.x, vec1.y * vec2.y, vec1.z * vec2.z};
-};
+}
 
 Vector divide(Vector vec1, Vector vec2)
 {
     return (Vector){vec1.x / vec2.x, vec1.y / vec2.y, vec1.z / vec2.z};
-};
+}
 
 double dot(Vector vec1, Vector vec2)
 {
     return vec1.x * vec2.x + vec1.y * vec2.y + vec1.z * vec2.z;
-};
+}
 
 double magnitude(Vector vec)
 {
     return sqrt(dot(vec, vec));
-};
+}
 
 struct opti_norm normalize(Vector vec)
 {
@@ -72,7 +74,7 @@ struct opti_norm normalize(Vector vec)
         r.vector = (Vector){vec.x / r.magnitude, vec.y / r.magnitude, vec.z / r.magnitude};
 
     return r;
-};
+}
 
 Vector flatten(Vector vec)
 {
@@ -82,12 +84,12 @@ Vector flatten(Vector vec)
 double angle(Vector vec1, Vector vec2)
 {
     return acos(cap(dot(normalize(vec1).vector, normalize(vec2).vector), -1, 1));
-};
+}
 
 Vector cross(Vector vec1, Vector vec2)
 {
     return (Vector){(vec1.y * vec2.z) - (vec1.z * vec2.y), (vec1.z * vec2.x) - (vec1.x * vec2.z), (vec1.x * vec2.y) - (vec1.y * vec2.x)};
-};
+}
 
 Vector double_to_vector(double num)
 {
@@ -123,10 +125,10 @@ Vector clamp(Vector vec, Vector start, Vector end)
     return s;
 }
 
-double distance(Vector vec1, Vector vec2)
+double dist(Vector vec1, Vector vec2)
 {
     return magnitude(sub(vec1, vec2));
-};
+}
 
 // Main lib
 
@@ -181,7 +183,70 @@ double find_slope(Vector shot_vector, Vector car_to_target)
     return max(min(d / e, 3), -3);
 };
 
-struct jump_shot parse_slice_for_jump_shot_with_target(double time_remaining, double best_shot_value, Vector ball_location, Vector car_location, Vector car_forward, int car_boost, Vector left_target, Vector right_target, double cap_)
+double throttle_acceleration(double car_velocity_x)
+{
+    if (car_velocity_x >= 1410)
+        return 0;
+
+    double x0, y0, x1, y1;
+    if (car_velocity_x < 1400) {
+        x0 = 0;
+        y0 = 1600;
+        x1 = 1400;
+        y1 = 160;
+    } else {
+        x0 = 1400;
+        y0 = 160;
+        x1 = 1410;
+        y1 = 0;
+    }
+
+    return y0 + ((y1-y0)/(x1-x0)) * (car_velocity_x - x0);
+}
+
+double car_drive_to_target_simulation(double boost_accel, double car_to_target, double car_speed, int car_boost)
+{
+    double b = car_boost;
+    double t = 0;
+    double v = car_speed;
+    double d = car_to_target;
+    _Bool b_a;
+
+    while (d > 50) {
+        b_a = 0;
+
+        if (b > boost_consumption * simulation_dt && v < max_speed - (boost_accel * simulation_dt)) {
+            b_a = 1;
+            v += boost_accel * simulation_dt;
+            b -= boost_consumption * simulation_dt;
+        }
+
+        v += throttle_acceleration(v) * simulation_dt;
+
+        d -= v * simulation_dt;
+        t += simulation_dt;
+    }
+
+    return t;
+}
+
+double car_turn_simulation(double turning_time, double car_speed)
+{
+    double t = turning_time;
+    double v = car_speed;
+    
+    while (t >= simulation_dt) {
+        if (v > 1410)
+            v -= 100 * simulation_dt;
+
+        v += throttle_acceleration(v) * simulation_dt;
+        t -= simulation_dt;
+    }
+
+    return v;
+}
+
+struct jump_shot parse_slice_for_jump_shot_with_target(double time_remaining, double best_shot_value, Vector ball_location, Vector car_location, Vector car_forward, int car_boost, Vector left_target, Vector right_target, double boost_accel, double car_speed)
 {
     struct jump_shot r;
     r.found = -1;
@@ -192,13 +257,16 @@ struct jump_shot parse_slice_for_jump_shot_with_target(double time_remaining, do
     double distance = car_to_ball_norm.magnitude;
 
     double forward_angle = angle(flatten(direction), flatten(car_forward));
-    double backward_angle = Py_MATH_PI - forward_angle;
+    double backward_angle = Py_MATH_PIl - forward_angle;
 
-    double forward_time = time_remaining - (forward_angle * 0.318);
-    double backward_time = time_remaining - (backward_angle * 0.418);
+    double forward_turn_time = forward_angle * 0.318;
+    double backward_turn_time = backward_angle * 0.418;
 
-    _Bool forward_flag = forward_time > 0 && (distance / forward_time) < ((car_boost > distance / 100) ? 2275 : 1400);
-    _Bool backward_flag = backward_time > 0 && distance < 1500 && (distance * 1.05 / backward_time) < 1200;
+    double forward_time = time_remaining - forward_turn_time;
+    double backward_time = time_remaining - backward_turn_time;
+
+    _Bool forward_flag = forward_time > 0 && forward_time > car_drive_to_target_simulation(boost_accel, distance, car_turn_simulation(forward_turn_time, car_speed), car_boost);
+    _Bool backward_flag = backward_time > 0 && distance < 1500 && backward_time > car_drive_to_target_simulation(boost_accel, distance, car_turn_simulation(backward_turn_time, car_speed), 0);
 
     if (forward_flag || backward_flag)
     {
@@ -221,7 +289,7 @@ struct jump_shot parse_slice_for_jump_shot_with_target(double time_remaining, do
     return r;
 };
 
-struct jump_shot parse_slice_for_jump_shot(double time_remaining, double best_shot_value, Vector ball_location, Vector car_location, Vector car_forward, int car_boost, double cap_)
+struct jump_shot parse_slice_for_jump_shot(double time_remaining, double best_shot_value, Vector ball_location, Vector car_location, Vector car_forward, int car_boost, double boost_accel, double car_speed)
 {
     struct jump_shot r;
     r.found = -1;
@@ -232,13 +300,16 @@ struct jump_shot parse_slice_for_jump_shot(double time_remaining, double best_sh
     double distance = car_to_ball_norm.magnitude;
 
     double forward_angle = angle(flatten(direction), flatten(car_forward));
-    double backward_angle = Py_MATH_PI - forward_angle;
+    double backward_angle = Py_MATH_PIl - forward_angle;
 
-    double forward_time = time_remaining - (forward_angle * 0.318);
-    double backward_time = time_remaining - (backward_angle * 0.418);
+    double forward_turn_time = forward_angle * 0.318;
+    double backward_turn_time = backward_angle * 0.418;
 
-    _Bool forward_flag = forward_time > 0 && (distance / forward_time) < ((car_boost > distance / 100) ? 2275 : 1400);
-    _Bool backward_flag = backward_time > 0 && (distance * 1.05 / backward_time) < 1200;
+    double forward_time = time_remaining - forward_turn_time;
+    double backward_time = time_remaining - backward_turn_time;
+
+    _Bool forward_flag = forward_time > 0 && forward_time > car_drive_to_target_simulation(boost_accel, distance, car_turn_simulation(forward_turn_time, car_speed), car_boost);
+    _Bool backward_flag = backward_time > 0 && distance < 1500 && backward_time > car_drive_to_target_simulation(boost_accel, distance, car_turn_simulation(backward_turn_time, car_speed), 0);
 
     r.best_shot_vector = direction;
 
@@ -252,7 +323,7 @@ struct jump_shot parse_slice_for_jump_shot(double time_remaining, double best_sh
     return r;
 };
 
-struct jump_shot parse_slice_for_double_jump_with_target(double time_remaining, double best_shot_value, Vector ball_location, Vector car_location, Vector car_forward, int car_boost, Vector left_target, Vector right_target, double cap_)
+struct jump_shot parse_slice_for_double_jump_with_target(double time_remaining, double best_shot_value, Vector ball_location, Vector car_location, Vector car_forward, int car_boost, Vector left_target, Vector right_target, double boost_accel, double car_speed)
 {
     struct jump_shot r;
     r.found = -1;
@@ -261,9 +332,11 @@ struct jump_shot parse_slice_for_double_jump_with_target(double time_remaining,
     struct opti_norm car_to_ball_norm = normalize(car_to_ball);
     Vector direction = car_to_ball_norm.vector;
     double distance = car_to_ball_norm.magnitude;
-    double forward_time = time_remaining - (angle(flatten(direction), flatten(car_forward)) * 0.318);
 
-    if (forward_time > 0 && (distance / forward_time) < ((car_boost > distance / 100) ? 2275 : 1400))
+    double forward_turn_time = angle(flatten(direction), flatten(car_forward)) * 0.318;
+    double forward_time = time_remaining - forward_turn_time;
+
+    if (forward_time > 0 && forward_time > car_drive_to_target_simulation(boost_accel, distance, car_turn_simulation(forward_turn_time, car_speed), car_boost))
     {
         struct post_correction pst_crrctn = correct_for_posts(ball_location, left_target, right_target);
         if (!pst_crrctn.swapped)
@@ -280,7 +353,7 @@ struct jump_shot parse_slice_for_double_jump_with_target(double time_remaining,
     return r;
 };
 
-struct jump_shot parse_slice_for_double_jump(double time_remaining, double best_shot_value, Vector ball_location, Vector car_location, Vector car_forward, int car_boost, double cap_)
+struct jump_shot parse_slice_for_double_jump(double time_remaining, double best_shot_value, Vector ball_location, Vector car_location, Vector car_forward, int car_boost, double boost_accel, double car_speed)
 {
     struct jump_shot r;
     r.found = -1;
@@ -289,11 +362,13 @@ struct jump_shot parse_slice_for_double_jump(double time_remaining, double best_
     struct opti_norm car_to_ball_norm = normalize(car_to_ball);
     Vector direction = car_to_ball_norm.vector;
     double distance = car_to_ball_norm.magnitude;
-    double forward_time = time_remaining - (angle(flatten(direction), flatten(car_forward)) * 0.318);
+
+    double forward_turn_time = angle(flatten(direction), flatten(car_forward)) * 0.318;
+    double forward_time = time_remaining - forward_turn_time;
 
     r.best_shot_vector = direction;
 
-    if (forward_time > 0 && (distance / forward_time) < ((car_boost > distance / 100) ? 2275 : 1400) && find_slope(r.best_shot_vector, car_to_ball) > 0)
+    if (forward_time > 0 && in_field(sub(ball_location, multiply(r.best_shot_vector, double_to_vector(best_shot_value))), 1) && forward_time > car_drive_to_target_simulation(boost_accel, distance, car_turn_simulation(forward_turn_time, car_speed), car_boost))
         r.found = 1;
 
     return r;
@@ -346,7 +421,7 @@ _Bool is_viable(double time_remaining, double hitbox_height, double boost_accel,
     return enough_speed && enough_boost && enough_time;
 };
 
-struct aerial_shot parse_slice_for_aerial_shot_with_target(double time_remaining, double best_shot_value, double boost_accel, Vector gravity, Vector ball_location, struct car me, Vector left_target, Vector right_target, double cap_)
+struct aerial_shot parse_slice_for_aerial_shot_with_target(double time_remaining, double best_shot_value, double boost_accel, Vector gravity, Vector ball_location, struct car me, Vector left_target, Vector right_target)
 {
     struct aerial_shot r;
     r.found = -1;
@@ -372,7 +447,7 @@ struct aerial_shot parse_slice_for_aerial_shot_with_target(double time_remaining
     return r;
 };
 
-struct aerial_shot parse_slice_for_aerial_shot(double time_remaining, double best_shot_value, double boost_accel, Vector gravity, Vector ball_location, struct car me, double cap_)
+struct aerial_shot parse_slice_for_aerial_shot(double time_remaining, double best_shot_value, double boost_accel, Vector gravity, Vector ball_location, struct car me)
 {
     struct aerial_shot r;
     r.found = -1;
@@ -393,13 +468,22 @@ struct aerial_shot parse_slice_for_aerial_shot(double time_remaining, double bes
 static PyObject *method_parse_slice_for_jump_shot_with_target(PyObject *self, PyObject *args)
 {
     int car_boost;
-    double time_remaining, best_shot_value, cap_;
+    double time_remaining, best_shot_value, boost_accel, car_speed, cap_;
     Vector ball_location, car_location, car_forward, left_target, right_target;
 
-    if (!PyArg_ParseTuple(args, "dd(ddd)(ddd)(ddd)i(ddd)(ddd)d", &time_remaining, &best_shot_value, &ball_location.x, &ball_location.y, &ball_location.z, &car_location.x, &car_location.y, &car_location.z, &car_forward.x, &car_forward.y, &car_forward.z, &car_boost, &left_target.x, &left_target.y, &left_target.z, &right_target.x, &right_target.y, &right_target.z, &cap_))
-        return NULL;
+    // new args are for >=1.8
+    if (!PyArg_ParseTuple(args, "ddd(ddd)(ddd)(ddd)id(ddd)(ddd)", &time_remaining, &best_shot_value, &boost_accel, &ball_location.x, &ball_location.y, &ball_location.z, &car_location.x, &car_location.y, &car_location.z, &car_forward.x, &car_forward.y, &car_forward.z, &car_boost, &car_speed, &left_target.x, &left_target.y, &left_target.z, &right_target.x, &right_target.y, &right_target.z)) {
+        // old args are for <1.8 and >=1.7
+        // cap_ is no longer needed, but a lot of instances still pass it in as an argument; this is why it's optional
+        PyErr_Clear();
+        if (!PyArg_ParseTuple(args, "dd(ddd)(ddd)(ddd)i(ddd)(ddd)d", &time_remaining, &best_shot_value, &ball_location.x, &ball_location.y, &ball_location.z, &car_location.x, &car_location.y, &car_location.z, &car_forward.x, &car_forward.y, &car_forward.z, &car_boost, &left_target.x, &left_target.y, &left_target.z, &right_target.x, &right_target.y, &right_target.z, &cap_))
+            return NULL;
 
-    struct jump_shot data_struct = parse_slice_for_jump_shot_with_target(time_remaining, best_shot_value, ball_location, car_location, car_forward, car_boost, left_target, right_target, cap_);
+        boost_accel = 991. + (2. / 3.);
+        car_speed = 0;
+    }
+
+    struct jump_shot data_struct = parse_slice_for_jump_shot_with_target(time_remaining, best_shot_value, ball_location, car_location, car_forward, car_boost, left_target, right_target, boost_accel, car_speed);
 
     return Py_BuildValue("{s:i,s:(ddd)}", "found", data_struct.found, "best_shot_vector", data_struct.best_shot_vector.x, data_struct.best_shot_vector.y, data_struct.best_shot_vector.z);
 };
@@ -407,13 +491,22 @@ static PyObject *method_parse_slice_for_jump_shot_with_target(PyObject *self, Py
 static PyObject *method_parse_slice_for_jump_shot(PyObject *self, PyObject *args)
 {
     int car_boost;
-    double time_remaining, best_shot_value, cap_;
+    double time_remaining, best_shot_value, boost_accel, car_speed, cap_;
     Vector ball_location, car_location, car_forward;
 
-    if (!PyArg_ParseTuple(args, "dd(ddd)(ddd)(ddd)id", &time_remaining, &best_shot_value, &ball_location.x, &ball_location.y, &ball_location.z, &car_location.x, &car_location.y, &car_location.z, &car_forward.x, &car_forward.y, &car_forward.z, &car_boost, &cap_))
-        return NULL;
+    // new args are for >=1.8
+    if (!PyArg_ParseTuple(args, "ddd(ddd)(ddd)(ddd)id", &time_remaining, &best_shot_value, &boost_accel, &ball_location.x, &ball_location.y, &ball_location.z, &car_location.x, &car_location.y, &car_location.z, &car_forward.x, &car_forward.y, &car_forward.z, &car_boost, &car_speed)) {
+        // old args are for <1.8 and >=1.7
+        // cap_ is no longer needed, but a lot of instances still pass it in as an argument; this is why it's optional
+        PyErr_Clear();
+        if (!PyArg_ParseTuple(args, "dd(ddd)(ddd)(ddd)i|d", &time_remaining, &best_shot_value, &ball_location.x, &ball_location.y, &ball_location.z, &car_location.x, &car_location.y, &car_location.z, &car_forward.x, &car_forward.y, &car_forward.z, &car_boost, &cap_))
+            return NULL;
+        
+        boost_accel = 991. + (2. / 3.);
+        car_speed = 0;
 
-    struct jump_shot data_struct = parse_slice_for_jump_shot(time_remaining, best_shot_value, ball_location, car_location, car_forward, car_boost, cap_);
+    }
+    struct jump_shot data_struct = parse_slice_for_jump_shot(time_remaining, best_shot_value, ball_location, car_location, car_forward, car_boost, boost_accel, car_speed);
 
     return Py_BuildValue("{s:i,s:(ddd)}", "found", data_struct.found, "best_shot_vector", data_struct.best_shot_vector.x, data_struct.best_shot_vector.y, data_struct.best_shot_vector.z);
 };
@@ -421,13 +514,22 @@ static PyObject *method_parse_slice_for_jump_shot(PyObject *self, PyObject *args
 static PyObject *method_parse_slice_for_double_jump_with_target(PyObject *self, PyObject *args)
 {
     int car_boost;
-    double time_remaining, best_shot_value, cap_;
+    double time_remaining, best_shot_value, boost_accel, car_speed, cap_;
     Vector ball_location, car_location, car_forward, left_target, right_target;
 
-    if (!PyArg_ParseTuple(args, "dd(ddd)(ddd)(ddd)i(ddd)(ddd)d", &time_remaining, &best_shot_value, &ball_location.x, &ball_location.y, &ball_location.z, &car_location.x, &car_location.y, &car_location.z, &car_forward.x, &car_forward.y, &car_forward.z, &car_boost, &left_target.x, &left_target.y, &left_target.z, &right_target.x, &right_target.y, &right_target.z, &cap_))
-        return NULL;
+    // new args are for >=1.8
+    if (!PyArg_ParseTuple(args, "ddd(ddd)(ddd)(ddd)id(ddd)(ddd)", &time_remaining, &best_shot_value, &boost_accel, &ball_location.x, &ball_location.y, &ball_location.z, &car_location.x, &car_location.y, &car_location.z, &car_forward.x, &car_forward.y, &car_forward.z, &car_boost, &car_speed, &left_target.x, &left_target.y, &left_target.z, &right_target.x, &right_target.y, &right_target.z)) {
+        // old args are for <1.8 and >=1.7
+        // cap_ is no longer needed, but a lot of instances still pass it in as an argument; this is why it's optional
+        PyErr_Clear();
+        if (!PyArg_ParseTuple(args, "dd(ddd)(ddd)(ddd)i(ddd)(ddd)|d", &time_remaining, &best_shot_value, &ball_location.x, &ball_location.y, &ball_location.z, &car_location.x, &car_location.y, &car_location.z, &car_forward.x, &car_forward.y, &car_forward.z, &car_boost, &left_target.x, &left_target.y, &left_target.z, &right_target.x, &right_target.y, &right_target.z, &cap_))
+            return NULL;
+        
+        boost_accel = 991. + (2. / 3.);
+        car_speed = 0;
+    }
 
-    struct jump_shot data_struct = parse_slice_for_double_jump_with_target(time_remaining, best_shot_value, ball_location, car_location, car_forward, car_boost, left_target, right_target, cap_);
+    struct jump_shot data_struct = parse_slice_for_double_jump_with_target(time_remaining, best_shot_value, ball_location, car_location, car_forward, car_boost, left_target, right_target, boost_accel, car_speed);
 
     return Py_BuildValue("{s:i,s:(ddd)}", "found", data_struct.found, "best_shot_vector", data_struct.best_shot_vector.x, data_struct.best_shot_vector.y, data_struct.best_shot_vector.z);
 };
@@ -435,13 +537,22 @@ static PyObject *method_parse_slice_for_double_jump_with_target(PyObject *self,
 static PyObject *method_parse_slice_for_double_jump(PyObject *self, PyObject *args)
 {
     int car_boost;
-    double time_remaining, best_shot_value, cap_;
+    double time_remaining, best_shot_value, boost_accel, car_speed, cap_;
     Vector ball_location, car_location, car_forward;
 
-    if (!PyArg_ParseTuple(args, "dd(ddd)(ddd)(ddd)id", &time_remaining, &best_shot_value, &ball_location.x, &ball_location.y, &ball_location.z, &car_location.x, &car_location.y, &car_location.z, &car_forward.x, &car_forward.y, &car_forward.z, &car_boost, &cap_))
-        return NULL;
+    // new args are for >=1.8
+    if (!PyArg_ParseTuple(args, "ddd(ddd)(ddd)(ddd)id", &time_remaining, &best_shot_value, &boost_accel, &ball_location.x, &ball_location.y, &ball_location.z, &car_location.x, &car_location.y, &car_location.z, &car_forward.x, &car_forward.y, &car_forward.z, &car_boost, &car_speed)) {
+        // old args are for <1.8 and >=1.7
+        // cap_ is no longer needed, but a lot of instances still pass it in as an argument; this is why it's optional
+        PyErr_Clear();
+        if (!PyArg_ParseTuple(args, "dd(ddd)(ddd)(ddd)i|d", &time_remaining, &best_shot_value, &ball_location.x, &ball_location.y, &ball_location.z, &car_location.x, &car_location.y, &car_location.z, &car_forward.x, &car_forward.y, &car_forward.z, &car_boost, &cap_))
+            return NULL;
+        
+        boost_accel = 991. + (2. / 3.);
+        car_speed = 0;
+    }
 
-    struct jump_shot data_struct = parse_slice_for_double_jump(time_remaining, best_shot_value, ball_location, car_location, car_forward, car_boost, cap_);
+    struct jump_shot data_struct = parse_slice_for_double_jump(time_remaining, best_shot_value, ball_location, car_location, car_forward, car_boost, boost_accel, car_speed);
 
     return Py_BuildValue("{s:i,s:(ddd)}", "found", data_struct.found, "best_shot_vector", data_struct.best_shot_vector.x, data_struct.best_shot_vector.y, data_struct.best_shot_vector.z);
 };
@@ -452,10 +563,11 @@ static PyObject *method_parse_slice_for_aerial_shot_with_target(PyObject *self,
     double time_remaining, best_shot_value, boost_accel, cap_;
     Vector gravity, ball_location, left_target, right_target;
 
-    if (!PyArg_ParseTuple(args, "ddd(ddd)(ddd)((ddd)(ddd)(ddd)(ddd)ii)(ddd)(ddd)d", &time_remaining, &best_shot_value, &boost_accel, &gravity.x, &gravity.y, &gravity.z, &ball_location.x, &ball_location.y, &ball_location.z, &me.location.x, &me.location.y, &me.location.z, &me.velocity.x, &me.velocity.y, &me.velocity.z, &me.up.x, &me.up.y, &me.up.z, &me.forward.x, &me.forward.y, &me.forward.z, &me.airborne, &me.boost, &left_target.x, &left_target.y, &left_target.z, &right_target.x, &right_target.y, &right_target.z, &cap_))
+    // cap_ is no longer needed, but a lot of instances still pass it in as an argument; this is why it's optional
+    if (!PyArg_ParseTuple(args, "ddd(ddd)(ddd)((ddd)(ddd)(ddd)(ddd)ii)(ddd)(ddd)|d", &time_remaining, &best_shot_value, &boost_accel, &gravity.x, &gravity.y, &gravity.z, &ball_location.x, &ball_location.y, &ball_location.z, &me.location.x, &me.location.y, &me.location.z, &me.velocity.x, &me.velocity.y, &me.velocity.z, &me.up.x, &me.up.y, &me.up.z, &me.forward.x, &me.forward.y, &me.forward.z, &me.airborne, &me.boost, &left_target.x, &left_target.y, &left_target.z, &right_target.x, &right_target.y, &right_target.z, &cap_))
         return NULL;
 
-    struct aerial_shot data_struct = parse_slice_for_aerial_shot_with_target(time_remaining, best_shot_value, boost_accel, gravity, ball_location, me, left_target, right_target, cap_);
+    struct aerial_shot data_struct = parse_slice_for_aerial_shot_with_target(time_remaining, best_shot_value, boost_accel, gravity, ball_location, me, left_target, right_target);
 
     return Py_BuildValue("{s:i,s:(ddd)}", "found", data_struct.found, "ball_intercept", data_struct.ball_intercept.x, data_struct.ball_intercept.y, data_struct.ball_intercept.z);
 };
@@ -466,10 +578,11 @@ static PyObject *method_parse_slice_for_aerial_shot(PyObject *self, PyObject *ar
     double time_remaining, best_shot_value, boost_accel, cap_;
     Vector gravity, ball_location;
 
-    if (!PyArg_ParseTuple(args, "ddd(ddd)(ddd)((ddd)(ddd)(ddd)(ddd)ii)d", &time_remaining, &best_shot_value, &boost_accel, &gravity.x, &gravity.y, &gravity.z, &ball_location.x, &ball_location.y, &ball_location.z, &me.location.x, &me.location.y, &me.location.z, &me.velocity.x, &me.velocity.y, &me.velocity.z, &me.up.x, &me.up.y, &me.up.z, &me.forward.x, &me.forward.y, &me.forward.z, &me.airborne, &me.boost, &cap_))
+    // cap_ is no longer needed, but a lot of instances still pass it in as an argument; this is why it's optional
+    if (!PyArg_ParseTuple(args, "ddd(ddd)(ddd)((ddd)(ddd)(ddd)(ddd)ii)|d", &time_remaining, &best_shot_value, &boost_accel, &gravity.x, &gravity.y, &gravity.z, &ball_location.x, &ball_location.y, &ball_location.z, &me.location.x, &me.location.y, &me.location.z, &me.velocity.x, &me.velocity.y, &me.velocity.z, &me.up.x, &me.up.y, &me.up.z, &me.forward.x, &me.forward.y, &me.forward.z, &me.airborne, &me.boost, &cap_))
         return NULL;
 
-    struct aerial_shot data_struct = parse_slice_for_aerial_shot(time_remaining, best_shot_value, boost_accel, gravity, ball_location, me, cap_);
+    struct aerial_shot data_struct = parse_slice_for_aerial_shot(time_remaining, best_shot_value, boost_accel, gravity, ball_location, me);
 
     return Py_BuildValue("{s:i,s:(ddd)}", "found", data_struct.found, "ball_intercept", data_struct.ball_intercept.x, data_struct.ball_intercept.y, data_struct.ball_intercept.z);
 };
